@@ -6,4 +6,4 @@ from .readers import read_raw
 from .writers import write_raw, writers
 
 
-__all__ = [read_raw, write_raw, writers]
+__all__ = ["read_raw", "write_raw", "writers"]
